<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Trax Logs for Moodle.
 *
 * @package    logstore_trax
 * @copyright  2018 Sébastien Fraysse {@link http://fraysse.eu}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace logstore_trax;

defined('MOODLE_INTERNAL') || die();

class Verbs {

    /**
     * Verbs.
     * 
     * @var array $verbs
     */
    protected $verbs = [
        
        'loggedin' => [
            'iri' => 'https://w3id.org/xapi/adl/verbs/logged-in',
        ],
        'loggedout' => [
            'iri' => 'https://w3id.org/xapi/adl/verbs/logged-out',
        ],
        'viewed' => [
            'iri' => 'https://vocab.xapi.fr/verbs/accessed',
        ],

    ];

    /**
     * Get a verb, given its code.
     * 
     * @param string $code Code of the verb
     * @return array
     */
    public function get(string $code) {
        return [
            'id' => $this->verbs[$code]['iri'],
        ];
    }



}
