# Best practices in designing xAPI Statements

## Vocabulary

There is currently no official xAPI profile regarding LMS or VLE activities.
I hope this project will be a contribution in defining such a profile. 

Most of the vocabulary used by this plugin is based on the http://vocab.xapi.fr domain.
Although it is not an official domain to define xAPI vocabulary, it is used as a temporary working domain,
where we can define a comprehensive and consistent set of concepts for the LMS/VLE purpose.

Ideally, this vocabulary will be replaced by an official one, based on the http://w3id.org/xapi domain,
when an xAPI LMS/VLE profile will be created. 
A matching vocabulary table will be released to facilitate migration of existing implementations. 


## Actors identification

Trax Logs uses the "account" identification format.

The "account.homePage" property identifies the Moodle platform supporting the activities.
Its value is based on a platform IRI, which must be set when configuring the plugin.
The platform IRI must be permanent. It may defer from the platform URL, which may change if the hosting domain or subdomain changes.

The "account.name" property identifies the actor, using an UUID generated by the plugin.
This UUID is permanent. It will not change if the user name, email or Moodle internal ID changes.

The other benefit of using such an UUID is that it garanties an anonymous identification.
Please, refer to the [data provacy documentation](privacy.md) for further details.


## Activities identification

Trax Logs generates a consistent IRI for all the activities, following a scheme based on the platform IRI,
the type of activity, and an UUID generated for each activity.

This approach garanties that we use permanent IRIs, and not URL which are subject to change
if the platform hosting domain changes.


## Activity types

Trax Logs systematically uses activity types, for all the activities of a Statement.

Activity types are related to:
* Structural activities: system, course, learning unit,
* Types of learning units: forum, chat, assignment, etc.
* Other types : xAPI profile, granularity level.

These activity types have been defined in a generic way:
* There is no reference to Moodle specific concept.
* There is no explicit reference to the LMS concept, because other kinds of platforms may support similar learning activities (cf MOOC, Web sites, etc).
* Some specific or technical concepts have been generalized (e.g. IMSCP and SCORM packages are just "content packages").

Please, refer to http://vocab.xapi.fr for further details.


## Contextual activities

Trax Logs defines for all the Statements:
* A "grouping" activity which identifies the Moodle platform in which the activity occurs (system),
* A "category" activity which identifies the xAPI profile used (currently http://vocab.xapi.fr/profiles/vle).

Trax Logs defines for all the Statements whose object is a learning unit (i.e. a Moodle course module):
* A "parent" activity which identifies the Moodle course in which the activity occurs,
* A "category" activity which mention the granularity level of the activity (i.e. learning unit).


## Descriptive elements

Trax Logs does not include actor names (anonymisation), neither verb displays.

Activity names and descriptions are included in Statement objects, but not in context activities.


## Extensions

Currently, no extension is used.

However, extensions may be used in the future in order to provide details related to activities and results.
Such extensions should not be based on Moodle specific concepts.


## Registration

Currently, the "registration" property is not used.

However, it may be used in the future at a learning unit level (i.e. Moodle modules) 
in order to make it easier to group all the Statements related to the same learning experience.


## Other elements

Trax Logs includes the following elements in all Statements:
* Version (1.0.3)
* Timestamp
* Context.platform (Moodle)

Statements IDs are not generated by the plugin.
